from . import reconstruction

def compute_feature_rect(data_container_array, feature_ids_array_path = None, feature_rect_array_path = None, observer = None) -> int:
  """Pythonic interface to ComputeFeatureRect Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    feature_rect_array_path (DataArrayPath): Sets the "FeatureRectArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.ComputeFeatureRect()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_rect_array_path is not None:
    filter.FeatureRectArrayPath = feature_rect_array_path
  filter.execute()
  return filter.ErrorCode

def partition_geometry(data_container_array, partitioning_mode = None, attribute_matrix_path = None, lower_left_coord = None, upper_right_coord = None, partitioning_scheme_origin = None, length_per_partition = None, number_of_partitions_per_axis = None, advanced_out_of_bounds_value = None, bounding_box_out_of_bounds_value = None, starting_partition_id = None, input_geometry_information = None, partitioning_scheme_information = None, partition_ids_array_name = None, save_partitioning_scheme = None, ps_data_container_path = None, ps_attribute_matrix_name = None, observer = None) -> int:
  """Pythonic interface to PartitionGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    partitioning_mode (int): Sets the "PartitioningMode" filter property
    attribute_matrix_path (DataArrayPath): Sets the "AttributeMatrixPath" filter property
    lower_left_coord (FloatVec3Type): Sets the "LowerLeftCoord" filter property
    upper_right_coord (FloatVec3Type): Sets the "UpperRightCoord" filter property
    partitioning_scheme_origin (FloatVec3Type): Sets the "PartitioningSchemeOrigin" filter property
    length_per_partition (FloatVec3Type): Sets the "LengthPerPartition" filter property
    number_of_partitions_per_axis (IntVec3Type): Sets the "NumberOfPartitionsPerAxis" filter property
    advanced_out_of_bounds_value (int): Sets the "AdvancedOutOfBoundsValue" filter property
    bounding_box_out_of_bounds_value (int): Sets the "BoundingBoxOutOfBoundsValue" filter property
    starting_partition_id (int): Sets the "StartingPartitionID" filter property
    input_geometry_information (QString): Sets the "InputGeometryInformation" filter property
    partitioning_scheme_information (QString): Sets the "PartitioningSchemeInformation" filter property
    partition_ids_array_name (QString): Sets the "PartitionIdsArrayName" filter property
    save_partitioning_scheme (bool): Sets the "SavePartitioningScheme" filter property
    ps_data_container_path (DataArrayPath): Sets the "PSDataContainerPath" filter property
    ps_attribute_matrix_name (QString): Sets the "PSAttributeMatrixName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.PartitionGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if partitioning_mode is not None:
    filter.PartitioningMode = partitioning_mode
  if attribute_matrix_path is not None:
    filter.AttributeMatrixPath = attribute_matrix_path
  if lower_left_coord is not None:
    filter.LowerLeftCoord = lower_left_coord
  if upper_right_coord is not None:
    filter.UpperRightCoord = upper_right_coord
  if partitioning_scheme_origin is not None:
    filter.PartitioningSchemeOrigin = partitioning_scheme_origin
  if length_per_partition is not None:
    filter.LengthPerPartition = length_per_partition
  if number_of_partitions_per_axis is not None:
    filter.NumberOfPartitionsPerAxis = number_of_partitions_per_axis
  if advanced_out_of_bounds_value is not None:
    filter.AdvancedOutOfBoundsValue = advanced_out_of_bounds_value
  if bounding_box_out_of_bounds_value is not None:
    filter.BoundingBoxOutOfBoundsValue = bounding_box_out_of_bounds_value
  if starting_partition_id is not None:
    filter.StartingPartitionID = starting_partition_id
  if input_geometry_information is not None:
    filter.InputGeometryInformation = input_geometry_information
  if partitioning_scheme_information is not None:
    filter.PartitioningSchemeInformation = partitioning_scheme_information
  if partition_ids_array_name is not None:
    filter.PartitionIdsArrayName = partition_ids_array_name
  if save_partitioning_scheme is not None:
    filter.SavePartitioningScheme = save_partitioning_scheme
  if ps_data_container_path is not None:
    filter.PSDataContainerPath = ps_data_container_path
  if ps_attribute_matrix_name is not None:
    filter.PSAttributeMatrixName = ps_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def group_features(data_container_array, contiguous_neighbor_list_array_path = None, non_contiguous_neighbor_list_array_path = None, use_non_contiguous_neighbors = None, patch_grouping = None, observer = None) -> int:
  """Pythonic interface to GroupFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    contiguous_neighbor_list_array_path (DataArrayPath): Sets the "ContiguousNeighborListArrayPath" filter property
    non_contiguous_neighbor_list_array_path (DataArrayPath): Sets the "NonContiguousNeighborListArrayPath" filter property
    use_non_contiguous_neighbors (bool): Sets the "UseNonContiguousNeighbors" filter property
    patch_grouping (bool): Sets the "PatchGrouping" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.GroupFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if contiguous_neighbor_list_array_path is not None:
    filter.ContiguousNeighborListArrayPath = contiguous_neighbor_list_array_path
  if non_contiguous_neighbor_list_array_path is not None:
    filter.NonContiguousNeighborListArrayPath = non_contiguous_neighbor_list_array_path
  if use_non_contiguous_neighbors is not None:
    filter.UseNonContiguousNeighbors = use_non_contiguous_neighbors
  if patch_grouping is not None:
    filter.PatchGrouping = patch_grouping
  filter.execute()
  return filter.ErrorCode

def merge_colonies(data_container_array, new_cell_feature_attribute_matrix_name = None, feature_ids_array_path = None, cell_phases_array_path = None, feature_phases_array_path = None, avg_quats_array_path = None, crystal_structures_array_path = None, cell_parent_ids_array_name = None, glob_alpha_array_name = None, feature_parent_ids_array_name = None, active_array_name = None, axis_tolerance = None, angle_tolerance = None, identify_glob_alpha = None, observer = None) -> int:
  """Pythonic interface to MergeColonies Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    new_cell_feature_attribute_matrix_name (QString): Sets the "NewCellFeatureAttributeMatrixName" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    cell_parent_ids_array_name (QString): Sets the "CellParentIdsArrayName" filter property
    glob_alpha_array_name (QString): Sets the "GlobAlphaArrayName" filter property
    feature_parent_ids_array_name (QString): Sets the "FeatureParentIdsArrayName" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    axis_tolerance (float): Sets the "AxisTolerance" filter property
    angle_tolerance (float): Sets the "AngleTolerance" filter property
    identify_glob_alpha (bool): Sets the "IdentifyGlobAlpha" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.MergeColonies()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_cell_feature_attribute_matrix_name is not None:
    filter.NewCellFeatureAttributeMatrixName = new_cell_feature_attribute_matrix_name
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if cell_parent_ids_array_name is not None:
    filter.CellParentIdsArrayName = cell_parent_ids_array_name
  if glob_alpha_array_name is not None:
    filter.GlobAlphaArrayName = glob_alpha_array_name
  if feature_parent_ids_array_name is not None:
    filter.FeatureParentIdsArrayName = feature_parent_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if axis_tolerance is not None:
    filter.AxisTolerance = axis_tolerance
  if angle_tolerance is not None:
    filter.AngleTolerance = angle_tolerance
  if identify_glob_alpha is not None:
    filter.IdentifyGlobAlpha = identify_glob_alpha
  filter.execute()
  return filter.ErrorCode

def merge_twins(data_container_array, new_cell_feature_attribute_matrix_name = None, axis_tolerance = None, angle_tolerance = None, feature_ids_array_path = None, feature_phases_array_path = None, avg_quats_array_path = None, crystal_structures_array_path = None, cell_parent_ids_array_name = None, feature_parent_ids_array_name = None, active_array_name = None, contiguous_neighbor_list_array_path = None, non_contiguous_neighbor_list_array_path = None, use_non_contiguous_neighbors = None, observer = None) -> int:
  """Pythonic interface to MergeTwins Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    new_cell_feature_attribute_matrix_name (QString): Sets the "NewCellFeatureAttributeMatrixName" filter property
    axis_tolerance (float): Sets the "AxisTolerance" filter property
    angle_tolerance (float): Sets the "AngleTolerance" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    cell_parent_ids_array_name (QString): Sets the "CellParentIdsArrayName" filter property
    feature_parent_ids_array_name (QString): Sets the "FeatureParentIdsArrayName" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    contiguous_neighbor_list_array_path (DataArrayPath): Sets the "ContiguousNeighborListArrayPath" filter property
    non_contiguous_neighbor_list_array_path (DataArrayPath): Sets the "NonContiguousNeighborListArrayPath" filter property
    use_non_contiguous_neighbors (bool): Sets the "UseNonContiguousNeighbors" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.MergeTwins()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_cell_feature_attribute_matrix_name is not None:
    filter.NewCellFeatureAttributeMatrixName = new_cell_feature_attribute_matrix_name
  if axis_tolerance is not None:
    filter.AxisTolerance = axis_tolerance
  if angle_tolerance is not None:
    filter.AngleTolerance = angle_tolerance
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if cell_parent_ids_array_name is not None:
    filter.CellParentIdsArrayName = cell_parent_ids_array_name
  if feature_parent_ids_array_name is not None:
    filter.FeatureParentIdsArrayName = feature_parent_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if contiguous_neighbor_list_array_path is not None:
    filter.ContiguousNeighborListArrayPath = contiguous_neighbor_list_array_path
  if non_contiguous_neighbor_list_array_path is not None:
    filter.NonContiguousNeighborListArrayPath = non_contiguous_neighbor_list_array_path
  if use_non_contiguous_neighbors is not None:
    filter.UseNonContiguousNeighbors = use_non_contiguous_neighbors
  filter.execute()
  return filter.ErrorCode

def segment_features(data_container_array, data_container_name = None, observer = None) -> int:
  """Pythonic interface to SegmentFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (QString): Sets the "DataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.SegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  filter.execute()
  return filter.ErrorCode

def c_axis_segment_features(data_container_array, cell_feature_attribute_matrix_name = None, misorientation_tolerance = None, use_good_voxels = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, good_voxels_array_path = None, feature_ids_array_name = None, active_array_name = None, randomize_feature_ids = None, observer = None) -> int:
  """Pythonic interface to CAxisSegmentFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_feature_attribute_matrix_name (QString): Sets the "CellFeatureAttributeMatrixName" filter property
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    randomize_feature_ids (bool): Sets the "RandomizeFeatureIds" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.CAxisSegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if randomize_feature_ids is not None:
    filter.RandomizeFeatureIds = randomize_feature_ids
  filter.execute()
  return filter.ErrorCode

def ebsd_segment_features(data_container_array, cell_feature_attribute_matrix_name = None, misorientation_tolerance = None, use_good_voxels = None, good_voxels_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, feature_ids_array_name = None, active_array_name = None, randomize_feature_ids = None, observer = None) -> int:
  """Pythonic interface to EBSDSegmentFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_feature_attribute_matrix_name (QString): Sets the "CellFeatureAttributeMatrixName" filter property
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    randomize_feature_ids (bool): Sets the "RandomizeFeatureIds" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.EBSDSegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if randomize_feature_ids is not None:
    filter.RandomizeFeatureIds = randomize_feature_ids
  filter.execute()
  return filter.ErrorCode

def scalar_segment_features(data_container_array, cell_feature_attribute_matrix_name = None, scalar_array_path = None, scalar_tolerance = None, use_good_voxels = None, good_voxels_array_path = None, feature_ids_array_name = None, active_array_name = None, randomize_feature_ids = None, observer = None) -> int:
  """Pythonic interface to ScalarSegmentFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_feature_attribute_matrix_name (QString): Sets the "CellFeatureAttributeMatrixName" filter property
    scalar_array_path (DataArrayPath): Sets the "ScalarArrayPath" filter property
    scalar_tolerance (float): Sets the "ScalarTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    active_array_name (QString): Sets the "ActiveArrayName" filter property
    randomize_feature_ids (bool): Sets the "RandomizeFeatureIds" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.ScalarSegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if scalar_array_path is not None:
    filter.ScalarArrayPath = scalar_array_path
  if scalar_tolerance is not None:
    filter.ScalarTolerance = scalar_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if randomize_feature_ids is not None:
    filter.RandomizeFeatureIds = randomize_feature_ids
  filter.execute()
  return filter.ErrorCode

def align_sections(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, write_alignment_shifts = None, alignment_shift_file_name = None, observer = None) -> int:
  """Pythonic interface to AlignSections Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    write_alignment_shifts (bool): Sets the "WriteAlignmentShifts" filter property
    alignment_shift_file_name (QString): Sets the "AlignmentShiftFileName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.AlignSections()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if write_alignment_shifts is not None:
    filter.WriteAlignmentShifts = write_alignment_shifts
  if alignment_shift_file_name is not None:
    filter.AlignmentShiftFileName = alignment_shift_file_name
  filter.execute()
  return filter.ErrorCode

def align_sections_feature(data_container_array, good_voxels_array_path = None, observer = None) -> int:
  """Pythonic interface to AlignSectionsFeature Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.AlignSectionsFeature()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  filter.execute()
  return filter.ErrorCode

def align_sections_feature_centroid(data_container_array, reference_slice = None, use_reference_slice = None, good_voxels_array_path = None, observer = None) -> int:
  """Pythonic interface to AlignSectionsFeatureCentroid Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    reference_slice (int): Sets the "ReferenceSlice" filter property
    use_reference_slice (bool): Sets the "UseReferenceSlice" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.AlignSectionsFeatureCentroid()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_slice is not None:
    filter.ReferenceSlice = reference_slice
  if use_reference_slice is not None:
    filter.UseReferenceSlice = use_reference_slice
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  filter.execute()
  return filter.ErrorCode

def align_sections_list(data_container_array, input_file = None, dream3_d_alignment_file = None, observer = None) -> int:
  """Pythonic interface to AlignSectionsList Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_file (QString): Sets the "InputFile" filter property
    dream3_d_alignment_file (bool): Sets the "DREAM3DAlignmentFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.AlignSectionsList()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file is not None:
    filter.InputFile = input_file
  if dream3_d_alignment_file is not None:
    filter.DREAM3DAlignmentFile = dream3_d_alignment_file
  filter.execute()
  return filter.ErrorCode

def align_sections_misorientation(data_container_array, misorientation_tolerance = None, use_good_voxels = None, quats_array_path = None, cell_phases_array_path = None, good_voxels_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """Pythonic interface to AlignSectionsMisorientation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.AlignSectionsMisorientation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def align_sections_mutual_information(data_container_array, misorientation_tolerance = None, use_good_voxels = None, quats_array_path = None, cell_phases_array_path = None, good_voxels_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """Pythonic interface to AlignSectionsMutualInformation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = reconstruction.AlignSectionsMutualInformation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

