from . import ucsbutilities

def clear_data_mask(data_container_array, mask_array_path = None, observer = None) -> int:
  """Pythonic interface to ClearDataMask Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.ClearDataMask()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  filter.execute()
  return filter.ErrorCode

def copy_attribute_array(data_container_array, selected_array_path = None, new_array_name = None, observer = None) -> int:
  """Pythonic interface to CopyAttributeArray Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_array_path (DataArrayPath): Sets the "SelectedArrayPath" filter property
    new_array_name (QString): Sets the "NewArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.CopyAttributeArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if new_array_name is not None:
    filter.NewArrayName = new_array_name
  filter.execute()
  return filter.ErrorCode

def copy_attribute_matrix(data_container_array, selected_attribute_matrix_path = None, new_attribute_matrix = None, observer = None) -> int:
  """Pythonic interface to CopyAttributeMatrix Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_attribute_matrix_path (DataArrayPath): Sets the "SelectedAttributeMatrixPath" filter property
    new_attribute_matrix (QString): Sets the "NewAttributeMatrix" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.CopyAttributeMatrix()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_attribute_matrix_path is not None:
    filter.SelectedAttributeMatrixPath = selected_attribute_matrix_path
  if new_attribute_matrix is not None:
    filter.NewAttributeMatrix = new_attribute_matrix
  filter.execute()
  return filter.ErrorCode

def copy_data_container(data_container_array, selected_data_container_name = None, new_data_container_name = None, observer = None) -> int:
  """Pythonic interface to CopyDataContainer Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    selected_data_container_name (DataArrayPath): Sets the "SelectedDataContainerName" filter property
    new_data_container_name (DataArrayPath): Sets the "NewDataContainerName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.CopyDataContainer()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_container_name is not None:
    filter.SelectedDataContainerName = selected_data_container_name
  if new_data_container_name is not None:
    filter.NewDataContainerName = new_data_container_name
  filter.execute()
  return filter.ErrorCode

def find_boundary_areas(data_container_array, surface_mesh_triangle_areas_array_path = None, surface_mesh_feature_face_ids_array_path = None, surface_mesh_boundary_areas_array_path = None, observer = None) -> int:
  """Pythonic interface to FindBoundaryAreas Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_triangle_areas_array_path (DataArrayPath): Sets the "SurfaceMeshTriangleAreasArrayPath" filter property
    surface_mesh_feature_face_ids_array_path (DataArrayPath): Sets the "SurfaceMeshFeatureFaceIdsArrayPath" filter property
    surface_mesh_boundary_areas_array_path (DataArrayPath): Sets the "SurfaceMeshBoundaryAreasArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.FindBoundaryAreas()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_triangle_areas_array_path is not None:
    filter.SurfaceMeshTriangleAreasArrayPath = surface_mesh_triangle_areas_array_path
  if surface_mesh_feature_face_ids_array_path is not None:
    filter.SurfaceMeshFeatureFaceIdsArrayPath = surface_mesh_feature_face_ids_array_path
  if surface_mesh_boundary_areas_array_path is not None:
    filter.SurfaceMeshBoundaryAreasArrayPath = surface_mesh_boundary_areas_array_path
  filter.execute()
  return filter.ErrorCode

def find_directional_moduli(data_container_array, feature_phases_array_path = None, crystal_structures_array_path = None, crystal_compliances_array_path = None, avg_quats_array_path = None, directional_moduli_array_name = None, loading_direction = None, observer = None) -> int:
  """Pythonic interface to FindDirectionalModuli Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    crystal_compliances_array_path (DataArrayPath): Sets the "CrystalCompliancesArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    directional_moduli_array_name (QString): Sets the "DirectionalModuliArrayName" filter property
    loading_direction (FloatVec3Type): Sets the "LoadingDirection" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.FindDirectionalModuli()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if crystal_compliances_array_path is not None:
    filter.CrystalCompliancesArrayPath = crystal_compliances_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if directional_moduli_array_name is not None:
    filter.DirectionalModuliArrayName = directional_moduli_array_name
  if loading_direction is not None:
    filter.LoadingDirection = loading_direction
  filter.execute()
  return filter.ErrorCode

def find_modulus_mismatch(data_container_array, moduli_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_delta_modulus_array_name = None, observer = None) -> int:
  """Pythonic interface to FindModulusMismatch Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    moduli_array_path (DataArrayPath): Sets the "ModuliArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_delta_modulus_array_name (QString): Sets the "SurfaceMeshDeltaModulusArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.FindModulusMismatch()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moduli_array_path is not None:
    filter.ModuliArrayPath = moduli_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_delta_modulus_array_name is not None:
    filter.SurfaceMeshDeltaModulusArrayName = surface_mesh_delta_modulus_array_name
  filter.execute()
  return filter.ErrorCode

def generate_misorientation_colors(data_container_array, reference_axis = None, reference_angle = None, cell_phases_array_path = None, quats_array_path = None, crystal_structures_array_path = None, good_voxels_array_path = None, misorientation_color_array_name = None, use_good_voxels = None, observer = None) -> int:
  """Pythonic interface to GenerateMisorientationColors Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    reference_axis (FloatVec3Type): Sets the "ReferenceAxis" filter property
    reference_angle (float): Sets the "ReferenceAngle" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    misorientation_color_array_name (QString): Sets the "MisorientationColorArrayName" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.GenerateMisorientationColors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_axis is not None:
    filter.ReferenceAxis = reference_axis
  if reference_angle is not None:
    filter.ReferenceAngle = reference_angle
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if misorientation_color_array_name is not None:
    filter.MisorientationColorArrayName = misorientation_color_array_name
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  filter.execute()
  return filter.ErrorCode

def input_crystal_compliances(data_container_array, compliances = None, crystal_compliances_array_path = None, observer = None) -> int:
  """Pythonic interface to InputCrystalCompliances Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    compliances (FloatVec21_t): Sets the "Compliances" filter property
    crystal_compliances_array_path (DataArrayPath): Sets the "CrystalCompliancesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = ucsbutilities.InputCrystalCompliances()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if compliances is not None:
    filter.Compliances = compliances
  if crystal_compliances_array_path is not None:
    filter.CrystalCompliancesArrayPath = crystal_compliances_array_path
  filter.execute()
  return filter.ErrorCode

